"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
const mocha_1 = require("@testdeck/mocha");
const chai_1 = require("chai");
const src_1 = require("../src");
const UnknownClassError_1 = require("./../src/exceptions/UnknownClassError");
const Product_1 = require("./classes/Product");
const Unknown_1 = require("./classes/Unknown");
let PlainArrayToClassTest = 
// eslint-disable-next-line @typescript-eslint/no-unused-vars
class PlainArrayToClassTest {
    normal() {
        const expected = [1, ['blue'], 2.2];
        const result = src_1.plainArrayToClass(Product_1.Product, expected);
        // basic
        chai_1.expect(result.constructor).equals(Product_1.Product);
        chai_1.expect(result).property('id', expected[0]);
        // nested
        chai_1.expect(result).property('color').not.null;
        chai_1.expect(result.color?.constructor).equals(Product_1.Color);
        chai_1.expect(result).property('color').property('name', expected[1][0]);
        // test class-transform
        chai_1.expect(result).property('price', +(+expected[2]).toFixed());
        chai_1.expect(result).property('displayPrice', new Product_1.Product().displayPrice);
    }
    empty() {
        const expected = new Product_1.Product();
        const result = src_1.plainArrayToClass(Product_1.Product, []);
        // basic
        chai_1.expect(result.constructor).equals(Product_1.Product);
        chai_1.expect(result).property('id', expected.id);
        // nested
        chai_1.expect(result).not.property('color');
        // test class-transform
        chai_1.expect(result).property('price', expected.price);
        chai_1.expect(result).property('displayPrice', expected.displayPrice);
    }
    nullValue() {
        const expected = [1, [null], 2.2];
        const result = src_1.plainArrayToClass(Product_1.Product, expected);
        // basic
        chai_1.expect(result.constructor).equals(Product_1.Product);
        chai_1.expect(result).property('id', expected[0]);
        // nested
        chai_1.expect(result).property('color').not.null;
        chai_1.expect(result.color?.constructor).equals(Product_1.Color);
        chai_1.expect(result).property('color').property('name', expected[1][0]);
        // test class-transform
        chai_1.expect(result).property('price', +(+expected[2]).toFixed());
        chai_1.expect(result).property('displayPrice', new Product_1.Product().displayPrice);
    }
    nullArray() {
        const expected = [1, null, 2.2];
        const result = src_1.plainArrayToClass(Product_1.Product, expected);
        // basic
        chai_1.expect(result.constructor).equals(Product_1.Product);
        chai_1.expect(result).property('id', expected[0]);
        // nested
        chai_1.expect(result).property('color').is.null;
        // test class-transform
        chai_1.expect(result).property('price', +expected[2].toFixed());
        chai_1.expect(result).property('displayPrice', new Product_1.Product().displayPrice);
    }
    emptyArray() {
        const expected = [1, [], 2.2];
        const result = src_1.plainArrayToClass(Product_1.Product, expected);
        // basic
        chai_1.expect(result.constructor).equals(Product_1.Product);
        chai_1.expect(result).property('id', expected[0]);
        // nested
        chai_1.expect(result).property('color').not.null;
        chai_1.expect(result.color?.constructor).equals(Product_1.Color);
        chai_1.expect(result).property('color').property('name', new Product_1.Color().name);
        // test class-transform
        chai_1.expect(result).property('price', +expected[2].toFixed());
        chai_1.expect(result).property('displayPrice', new Product_1.Product().displayPrice);
    }
    outOfIndex() {
        const expected = [1, ['blue'], 2.2, '0', 'out-of-index'];
        const result = src_1.plainArrayToClass(Product_1.Product, expected);
        // basic
        chai_1.expect(result.constructor).equals(Product_1.Product);
        chai_1.expect(result).property('id', expected[0]);
        // nested
        chai_1.expect(result).property('color').not.null;
        chai_1.expect(result.color?.constructor).equals(Product_1.Color);
        chai_1.expect(result).property('color').property('name', expected[1][0]);
        // test class-transform
        chai_1.expect(result).property('price', +(+expected[2]).toFixed());
        chai_1.expect(result).property('displayPrice', new Product_1.Product().displayPrice);
    }
    unknownClass() {
        chai_1.expect(() => src_1.plainArrayToClass(Unknown_1.UnknownClass, [])).throw(UnknownClassError_1.UnknownClassError);
    }
    unknownTypeWithoutValue() {
        chai_1.expect(() => src_1.plainArrayToClass(Unknown_1.UnknownTypeParent, [[]])).not.throw();
    }
    unknownType() {
        chai_1.expect(() => src_1.plainArrayToClass(Unknown_1.UnknownTypeParent, [[1]])).throw(src_1.UnknownTypeError);
    }
};
__decorate([
    mocha_1.test(),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], PlainArrayToClassTest.prototype, "normal", null);
__decorate([
    mocha_1.test(),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], PlainArrayToClassTest.prototype, "empty", null);
__decorate([
    mocha_1.test(),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], PlainArrayToClassTest.prototype, "nullValue", null);
__decorate([
    mocha_1.test(),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], PlainArrayToClassTest.prototype, "nullArray", null);
__decorate([
    mocha_1.test(),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], PlainArrayToClassTest.prototype, "emptyArray", null);
__decorate([
    mocha_1.test(),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], PlainArrayToClassTest.prototype, "outOfIndex", null);
__decorate([
    mocha_1.test(),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], PlainArrayToClassTest.prototype, "unknownClass", null);
__decorate([
    mocha_1.test(),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], PlainArrayToClassTest.prototype, "unknownTypeWithoutValue", null);
__decorate([
    mocha_1.test(),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], PlainArrayToClassTest.prototype, "unknownType", null);
PlainArrayToClassTest = __decorate([
    mocha_1.suite()
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
], PlainArrayToClassTest);
//# sourceMappingURL=plainArrayToClass.test.js.map